mafw.db.db\_wizard
==================

.. automodule:: mafw.db.db_wizard

   
   .. rubric:: Functions

   .. autosummary::
   
      dump_models
   
   .. rubric:: Classes

   .. autosummary::
   
      UnknownField
   